@@ -3,5 +3,5 @@
 
 from TechParser import parser
 
-def get_articles(start_page=1, end_page=2):
+def get_articles(*args, **kwargs):
 	return parser.get_articles_from_rss('http://droider.ru/feed/', 'droider')
